@@ -1,5 +1,8 @@
+# Environments where server url and api key are stored for global connection
 SERVER_URL_ENV_KEY = "AYON_SERVER_URL"
-SERVER_TOKEN_ENV_KEY = "AYON_TOKEN"
+SERVER_API_ENV_KEY = "AYON_API_KEY"
+# Backwards compatibility
+SERVER_TOKEN_ENV_KEY = SERVER_API_ENV_KEY
 
 # --- Project ---
 DEFAULT_PROJECT_FIELDS = {
@@ -67,7 +70,7 @@ DEFAULT_REPRESENTATION_FIELDS = {
 }
 
 REPRESENTATION_FILES_FIELDS = {
-    "files.baseName",
+    "files.name",
     "files.hash",
     "files.id",
     "files.path",
@@ -102,4 +105,4 @@ DEFAULT_EVENT_FIELDS = {
     "topic",
     "updatedAt",
     "user",
-}
\ No newline at end of file
+}
